SERVER_URL = 'http://localhost:5000'
WEB_URL = 'http://localhost:5000'
SLACK_BOT_TOKEN = ''
SLACK_CHANNEL = ''
AUTH0_DOMAIN = ''
SENTRY_DSN = ''
FLOAT_PROJECT_TOKEN = 'floating_project'
SAMPLES_PROJECT_TOKEN = 'samples'
LABML_VERSION = '0.4.112'
ANALYTICS_TO_SERVER = False
IS_LOCAL_SETUP = True
INDICATOR_LIMIT = 100
IS_LOGIN_REQUIRED = False
